package org.nst.pasientlink.authenticator;

/**
 * <p>Title: Request </p>
 * <p>Description: this helper class contains a authentication request, and is
 * used by the Authenticator class in order to manage requests.
 * </p>
 * <p>Copyright: Copyright (c) 2002</p>
 * <p>Company: Norwegian Centre for Telemedicine </p>
 * @author Thomas Strandens, Per Atle Bakkevoll
 * @version 1.0
 */

import java.util.*;

public class Request {

   private int requestTimeoutMinutes; // time allowed from request for authentication until authentication is actually performed
   private String userID;
   private String singleUsePassword;
   private Date creationDate;

   /**
    * Constructor. Sets creation date and other instance variables.
    *
    * @param myUserID String containing user id
    * @param timeoutMinutes int indicating number of minutes before request times out
    * @param mySingleUsePassword String containing single use password for request
    */

   public Request(int timeoutMinutes, String myUserID, String mySingleUsePassword) {
      this.requestTimeoutMinutes = timeoutMinutes;
      this.userID = myUserID;
      this.singleUsePassword = mySingleUsePassword;
      this.creationDate = new Date(System.currentTimeMillis());
   }

   /**
    * getUserID returns the userID for this request, or null if none has been set
    *
    * @return String containing the userID for this request, or null if none has been set
    */

   public String getUserID() {
      return this.userID;
   }

   /**
    * getSingleUsePassword returns the single use password for this request,
    * or null if none has been set
    *
    * @return String containing the single use password for this request, or null if none has been set
    */

   public String getSingleUsePassword() {
      return this.singleUsePassword;
   }

   /**
    * isTimedOut returns true if the request has timed out, according
    * to the timeout policy.
    *
    * @return boolean indicating whether or not the request has timed out.
    */

   public boolean isTimedOut() {
      boolean retVal = false;
      long timeoutMilliseconds = (long) this.requestTimeoutMinutes * 60 * 1000;
      if((System.currentTimeMillis() - creationDate.getTime()) > timeoutMilliseconds) {
         retVal = true;
      }
      return retVal;
   }
}